<?php
/**
 * Plugin Name: Custom Email Sender
 * Plugin URI: https://neoslab.com/plugins/custom-email-sender/
 * Description: Change the default email address and sender name output for all message sent from your WP dashboard.
 * Version: 2.0.5
 * Author: NeosLab
 * Author URI: https://neoslab.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: custom-email-sender
 * Domain Path: /languages
*/

/**
 * Prevent file to be called directly
*/
if((!defined('WPINC')) || ('custom-email-sender.php' == basename($_SERVER['SCRIPT_FILENAME'])))
{
	die;
}

/**
 * Define Constants
*/
define('CES_PLUGIN_FULLNAME', 'Custom Email Sender');
define('CES_PLUGIN_VERSION', '2.0.5');
define('CES_PLUGIN_LAST_RELEASE', '2019/06/10');
define('CES_PLUGIN_LANGUAGES', 'English, French, Spanish');

/**
 * The code that runs during plugin activation
 * This action is documented in includes/class-custom-email-sender-activator.php
*/
if(!function_exists('activate_custom_email_sender'))
{
	function activate_custom_email_sender() 
	{
		require_once plugin_dir_path(__FILE__).'includes/class-custom-email-sender-activation.php';
		Custom_Email_Sender_Activation::activate();
	}

	register_activation_hook(__FILE__, 'activate_custom_email_sender');
}

/**
 * The code that runs during plugin deactivation
 * This action is documented in includes/class-custom-email-sender-deactivator.php
*/
if(!function_exists('deactivate_custom_email_sender'))
{
	function deactivate_custom_email_sender() 
	{
		require_once plugin_dir_path(__FILE__).'includes/class-custom-email-sender-deactivation.php';
		Custom_Email_Sender_Deactivation::deactivate();
	}

	register_deactivation_hook(__FILE__, 'deactivate_custom_email_sender');
}

/**
 * The core plugin class that is used to define internationalization
 * admin-specific hooks and public-facing site hooks.
*/
require plugin_dir_path(__FILE__).'includes/class-custom-email-sender-core.php';

/**
 * Begins execution of the plugin
*/
if(!function_exists('run_custom_email_sender'))
{
	function run_custom_email_sender() 
	{
		$plugin = new Custom_Email_Sender_Core();
		$plugin->run();
	}

	run_custom_email_sender();
}

?>